#!/usr/bin/env python3
# MIT License
#
# Copyright (c) 2020 Kaede Hoshikawa
#
# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"), to
# deal in the Software without restriction, including without limitation the
# rights to use, copy, modify, merge, publish, distribute, sublicense, and/or
# sell copies of the Software, and to permit persons to whom the Software is
# furnished to do so, subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included in
# allcopies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
# SOFTWARE.

from setuptools import setup, find_packages

import sys

if not sys.version_info[:3] >= (3, 5, 1):
    raise RuntimeError("Destination requires Python 3.5.1 or higher.")

setup_requires = ["setuptools>=50.3.0",
                  "pytest-runner>=5.2,<6", "setuptools-scm>=4.1.2"]

install_requires = ["importlib-metadata>=1.7.0;python_version<'3.8'"]

tests_require = ["pytest>=6.0.1,<7"]

dev_requires = [
    "mypy>=0.782,<1",
    "flake8>=3.8.3,<4"]
dev_requires.extend(tests_require)

if __name__ == "__main__":
    setup(
        name="destination",
        use_scm_version={"local_scheme": lambda v: ""},
        author="Kaede Hoshikawa",
        author_email="futursolo@icloud.com",
        url="https://github.com/futursolo/destination",
        license="MIT",
        python_requires=">=3.5.1",
        description=("A Regex Based Path Routing Library."),
        long_description=open("README.rst", "r").read(),
        packages=find_packages(),
        package_data={"": ["*"]},
        include_package_data=True,
        setup_requires=setup_requires,
        install_requires=install_requires,
        tests_require=tests_require,
        extras_require={
            "test": tests_require,
            "dev": dev_requires,
        },
        zip_safe=False,
        classifiers=[
            "Operating System :: MacOS",
            "Operating System :: MacOS :: MacOS X",
            "Operating System :: Microsoft",
            "Operating System :: Microsoft :: Windows",
            "Operating System :: POSIX",
            "Operating System :: POSIX :: Linux",
            "Operating System :: Unix",
            "Programming Language :: Python",
            "Programming Language :: Python :: 3 :: Only",
            "Programming Language :: Python :: Implementation :: CPython"
        ]
    )
